@@ -24,7 +24,6 @@ from six.moves import urllib_parse
 
 
 class Test_get_expiration_seconds(unittest.TestCase):
-
     @staticmethod
     def _call_fut(expiration):
         from google.cloud.storage._signing import get_expiration_seconds
@@ -44,7 +43,7 @@ class Test_get_expiration_seconds(unittest.TestCase):
 
     def test_w_long(self):
         if six.PY3:
-            raise unittest.SkipTest('No long on Python 3')
+            raise unittest.SkipTest("No long on Python 3")
 
         self.assertEqual(self._call_fut(long(123)), 123)  # noqa: F821
 
@@ -64,7 +63,7 @@ class Test_get_expiration_seconds(unittest.TestCase):
         from google.cloud._helpers import _UTC
 
         class CET(_UTC):
-            _tzname = 'CET'
+            _tzname = "CET"
             _utcoffset = datetime.timedelta(hours=1)
 
         zone = CET()
@@ -79,8 +78,8 @@ class Test_get_expiration_seconds(unittest.TestCase):
         expiration_as_delta = datetime.timedelta(seconds=10)
 
         patch = mock.patch(
-            'google.cloud.storage._signing.NOW',
-            return_value=dummy_utcnow)
+            "google.cloud.storage._signing.NOW", return_value=dummy_utcnow
+        )
         with patch as utcnow:
             result = self._call_fut(expiration_as_delta)
 
@@ -93,8 +92,8 @@ class Test_get_expiration_seconds(unittest.TestCase):
         expiration_as_delta = datetime.timedelta(days=1)
 
         patch = mock.patch(
-            'google.cloud.storage._signing.NOW',
-            return_value=dummy_utcnow)
+            "google.cloud.storage._signing.NOW", return_value=dummy_utcnow
+        )
         with patch as utcnow:
             result = self._call_fut(expiration_as_delta)
 
@@ -103,51 +102,48 @@ class Test_get_expiration_seconds(unittest.TestCase):
 
 
 class Test_get_signed_query_params(unittest.TestCase):
-
     @staticmethod
     def _call_fut(credentials, expiration, string_to_sign):
         from google.cloud.storage._signing import get_signed_query_params
 
-        return get_signed_query_params(
-            credentials, expiration, string_to_sign)
+        return get_signed_query_params(credentials, expiration, string_to_sign)
 
     def test_it(self):
-        sig_bytes = b'DEADBEEF'
+        sig_bytes = b"DEADBEEF"
         account_name = mock.sentinel.service_account_email
-        credentials = _make_credentials(
-            signing=True, signer_email=account_name)
+        credentials = _make_credentials(signing=True, signer_email=account_name)
         credentials.sign_bytes.return_value = sig_bytes
         expiration = 100
-        string_to_sign = 'dummy_signature'
-        result = self._call_fut(
-            credentials, expiration, string_to_sign)
+        string_to_sign = "dummy_signature"
+        result = self._call_fut(credentials, expiration, string_to_sign)
 
         expected = {
-            'GoogleAccessId': account_name,
-            'Expires': str(expiration),
-            'Signature': base64.b64encode(sig_bytes),
+            "GoogleAccessId": account_name,
+            "Expires": str(expiration),
+            "Signature": base64.b64encode(sig_bytes),
         }
         self.assertEqual(result, expected)
         credentials.sign_bytes.assert_called_once_with(string_to_sign)
 
 
 class Test_generate_signed_url(unittest.TestCase):
-
     @staticmethod
     def _call_fut(*args, **kwargs):
         from google.cloud.storage._signing import generate_signed_url
 
         return generate_signed_url(*args, **kwargs)
 
-    def _generate_helper(self, response_type=None, response_disposition=None,
-                         generation=None):
-        endpoint = 'http://api.example.com'
-        resource = '/name/path'
+    def _generate_helper(
+        self, response_type=None, response_disposition=None, generation=None
+    ):
+        endpoint = "http://api.example.com"
+        resource = "/name/path"
         credentials = _make_credentials(
-            signing=True, signer_email='service@example.com')
-        credentials.sign_bytes.return_value = b'DEADBEEF'
+            signing=True, signer_email="service@example.com"
+        )
+        credentials.sign_bytes.return_value = b"DEADBEEF"
         signed = base64.b64encode(credentials.sign_bytes.return_value)
-        signed = signed.decode('ascii')
+        signed = signed.decode("ascii")
 
         expiration = 1000
         url = self._call_fut(
@@ -161,54 +157,54 @@ class Test_generate_signed_url(unittest.TestCase):
         )
 
         # Check the mock was called.
-        string_to_sign = '\n'.join([
-            'GET',
-            '',
-            '',
-            str(expiration),
-            resource,
-        ])
+        string_to_sign = "\n".join(["GET", "", "", str(expiration), resource])
         credentials.sign_bytes.assert_called_once_with(string_to_sign)
 
         scheme, netloc, path, qs, frag = urllib_parse.urlsplit(url)
-        self.assertEqual(scheme, 'http')
-        self.assertEqual(netloc, 'api.example.com')
+        self.assertEqual(scheme, "http")
+        self.assertEqual(netloc, "api.example.com")
         self.assertEqual(path, resource)
-        self.assertEqual(frag, '')
+        self.assertEqual(frag, "")
 
         # Check the URL parameters.
         params = urllib_parse.parse_qs(qs)
         expected_params = {
-            'GoogleAccessId': [credentials.signer_email],
-            'Expires': [str(expiration)],
-            'Signature': [signed],
+            "GoogleAccessId": [credentials.signer_email],
+            "Expires": [str(expiration)],
+            "Signature": [signed],
         }
         if response_type is not None:
-            expected_params['response-content-type'] = [response_type]
+            expected_params["response-content-type"] = [response_type]
         if response_disposition is not None:
-            expected_params['response-content-disposition'] = [
-                response_disposition]
+            expected_params["response-content-disposition"] = [response_disposition]
         if generation is not None:
-            expected_params['generation'] = [generation]
+            expected_params["generation"] = [generation]
         self.assertEqual(params, expected_params)
 
     def test_w_expiration_int(self):
         self._generate_helper()
 
     def test_w_custom_fields(self):
-        response_type = 'text/plain'
-        response_disposition = 'attachment; filename=blob.png'
-        generation = '123'
-        self._generate_helper(response_type=response_type,
-                              response_disposition=response_disposition,
-                              generation=generation)
+        response_type = "text/plain"
+        response_disposition = "attachment; filename=blob.png"
+        generation = "123"
+        self._generate_helper(
+            response_type=response_type,
+            response_disposition=response_disposition,
+            generation=generation,
+        )
 
     def test_with_google_credentials(self):
-        resource = '/name/path'
+        resource = "/name/path"
         credentials = _make_credentials()
         expiration = int(time.time() + 5)
-        self.assertRaises(AttributeError, self._call_fut, credentials,
-                          resource=resource, expiration=expiration)
+        self.assertRaises(
+            AttributeError,
+            self._call_fut,
+            credentials,
+            resource=resource,
+            expiration=expiration,
+        )
 
 
 def _make_credentials(signing=False, signer_email=None):
